/** @file
 *
 * @copyright &copy; Copyright 2007-2008 by Intra2net AG
 * @license commercial
 *
 * info@intra2net.com
 */

#include "source_track_basics.hpp"

#include <list>
#include <containerfunc.hpp>
#include <stringfunc.hxx>
#include <filefunc.hxx>


namespace I2n
{

/*
** implementation of SourceLocation
*/

SourceLocation::SourceLocation()
: Line ( 0 )
{
} // eo SourceLocation::SourceLocation()


SourceLocation::SourceLocation (
    const std::string& file,
    long line,
    const std::string& funcname
)
: File( file )
, Line( line )
, FunctionName( funcname )
{
} // eo SourceLocation::SourceLocation(const std::string&,long,const std::string&)


/**
 * @brief returns a "location tag"; i.e. a string which can be used to identify
 * the source location.
 * @return the location tag.
 */
std::string SourceLocation::get_location_tag() const
{
   static std::list< std::string > suffixes= TransientPushBackFiller< std::string, std::list >()
      ( ".cpp" ) ( ".cxx" ) ( ".cc" ) ( ".C" ) ( ".c++" )
      ( ".hpp" ) ( ".hxx" ) ( ".hh" ) ( ".H" ) ( ".h++" ) ( ".h" )
   ;
   if ( LocationTag.empty() and not File.empty() )
   {
      std::string str= basename( File );
      for( std::list< std::string >::const_iterator it= suffixes.begin();
           it != suffixes.end();
           ++it )
      {
         if ( has_suffix(str,*it) )
         {
            str= remove_suffix(str,*it);
            break;
         }
      }
      LocationTag= str;
      LocationTag+= "#";
      LocationTag+= to_string( Line );
   }
   return LocationTag;
} // eo SourceLocation::get_location_tag()



} // eo namespace I2n
