/** @file
 * @brief Implementation of intuitive tristate logic
 *
 * (c) Copyright 2011 by Intra2net AG
 * Written by Erich Willems and Thomas Jarosch
 * 
 * After we had serious trouble with the current boost::logic::tribool implementation
 * overloading the comparison operators, we rolled our own class.
 *
 * info@intra2net.com
 */

namespace I2n
{

class Tribool
{
public:
    enum State { False, True, Undef };

    Tribool();
    Tribool(const State &v);
    Tribool(const Tribool& src);

    // set element
    Tribool&        operator= (const State &v);
    Tribool&        operator= (const Tribool& src);

    // Element comparison
    bool operator==(const Tribool& v) const;
    bool operator!=(const Tribool& v) const;

    // logic operators
    Tribool operator !() const;
    Tribool operator ||(const Tribool& x) const;
    Tribool operator &&(const Tribool& x) const;

    // Bistate logic to tristate conversion
    Tribool(const bool &v);
    Tribool&        operator= (const bool &v);

    // comparision with bool (bi)
    bool    is_exact(const bool &v) const;

private:
    State Value;
};

}
